package com.ruoyi.project.patrol.dev.service;

import java.util.List;
import com.ruoyi.project.patrol.dev.domain.TDevCctv;

/**
 * CCTV系统Service接口
 * 
 * @author admin
 * @date 2023-11-03
 */
public interface ITDevCctvService 
{
    /**
     * 查询CCTV系统
     * 
     * @param id CCTV系统主键
     * @return CCTV系统
     */
    public TDevCctv selectTDevCctvById(Long id);

    /**
     * 查询CCTV系统列表
     * 
     * @param tDevCctv CCTV系统
     * @return CCTV系统集合
     */
    public List<TDevCctv> selectTDevCctvList(TDevCctv tDevCctv);

    /**
     * 新增CCTV系统
     * 
     * @param tDevCctv CCTV系统
     * @return 结果
     */
    public int insertTDevCctv(TDevCctv tDevCctv);

    /**
     * 修改CCTV系统
     * 
     * @param tDevCctv CCTV系统
     * @return 结果
     */
    public int updateTDevCctv(TDevCctv tDevCctv);

    /**
     * 批量删除CCTV系统
     * 
     * @param ids 需要删除的CCTV系统主键集合
     * @return 结果
     */
    public int deleteTDevCctvByIds(Long[] ids);

    /**
     * 删除CCTV系统信息
     * 
     * @param id CCTV系统主键
     * @return 结果
     */
    public int deleteTDevCctvById(Long id);
}
